pub struct TableCatalogState {
pub tables: Vec<TableState>,
pub next_table_id: TableId,
pub schemas: Vec<String>,
}Expand description
Serializable table catalog state for persistence.
This structure contains all information needed to restore a table catalog from disk, including all table and field mappings.
Fields
tables: Vec<TableState>All registered tables with their field resolvers
next_table_id: TableIdNext table ID to assign
schemas: Vec<String>All registered schema names (canonical lowercase)