Module expr

Module expr 

Structs

Filter
Single predicate against a field.
ScalarSubqueryExpr
Scalar subquery evaluated as part of a scalar expression.
SubqueryExpr
Correlated subquery used within a predicate expression.
SubqueryId
Metadata describing a correlated subquery.

Enums

AggregateCall
Aggregate function call within a scalar expression.
BinaryOp
Arithmetic operator for ScalarExpr.
CompareOp
Comparison operator for scalar expressions.
Expr
Logical expression over predicates.
Literal
A literal value that has not yet been coerced into a specific native type. This allows for type inference to be deferred until the column type is known.
LiteralCastError
Error converting a Literal into a concrete native type.
Operator
Comparison/matching operators over untyped Literals.
ScalarExpr
Arithmetic scalar expression that can reference multiple fields.

Traits

FromLiteral
Helper trait implemented for primitive types that can be produced from a Literal.
LiteralExt
Extension methods for working with Literal.